"""Advanced text alignment and semantic containment analysis tool."""

__version__ = "0.1.0"
__author__ = "WangYihang"
__email__ = "wangyihang@example.com"

from .core import (
    AlignmentResult,
    SemanticAligner,
    calculate_containment_score,
    split_paragraphs,
)

__all__ = [
    "AlignmentResult",
    "SemanticAligner", 
    "calculate_containment_score",
    "split_paragraphs",
] 